@@ -17,12 +17,17 @@ B<File::Remove> - Remove files and directories
     # removes (with recursion) several files and directories
     remove \1, qw( file1 file2 directory1 *~ );
 
+    # removes (with support for undeleting later) several files
+    undelete qw( *~ );
+
 =head1 DESCRIPTION
 
 B<File::Remove::remove> removes files and directories.  It acts like
-B<rm>, for the most part.  Although unlink can be given a list of files,
-it will not remove directories; this module remedies that.  It also
-accepts wildcards, * and ?, as arguments for filenames.
+B</bin/rm>, for the most part.  Although unlink can be given a list
+of files, it will not remove directories; this module remedies that.
+It also accepts wildcards, * and ?, as arguments for filenames.
+
+B<File::Remove::undelete> accepts the same arguments as B<remove>.
 
 =head1 METHODS
 
@@ -35,6 +40,7 @@ in B<rm -rf> if the first argument is a reference to a scalar that
 evaluates to true.  If the first arguemnt is a reference to a scalar
 then it is used as the value of the recursive flag.  By default it's
 false so only pass \1 to it.
+
 In list context it returns a list of files/directories removed, in
 scalar context it returns the number of files/directories removed.  The
 list/number should match what was passed in if everything went well.
@@ -44,6 +50,14 @@ list/number should match what was passed in if everything went well.
 Just calls remove.  It's there for people who get tired of typing
 'remove'.
 
+=item X<undelete>
+
+Removes files and directories, with support for undeleting later.
+Arguments are passed unmodified to B<remove>.
+
+Currently, undelete support is only available on Win32 platforms;
+the L<Win32::FileOp> module is required.
+
 =back
 
 =head1 BUGS
@@ -54,7 +68,7 @@ up-to-date bug listing.
 =head1 AUTHOR
 
 Taken over by Richard Soderberg, E<lt>perl@crystalflame.netE<gt>, so as
-to port it to L<File::Spec>.
+to port it to L<File::Spec> and add tests.
 
 Original copyright: (c) 1998 by Gabor Egressy, E<lt>gabor@vmunix.comE<gt>.
 
@@ -67,11 +81,11 @@ use strict;
 use vars qw(@EXPORT_OK @ISA $VERSION $debug);
 @ISA = qw(Exporter);
 # we export nothing by default :)
-@EXPORT_OK = qw(remove rm);
+@EXPORT_OK = qw(remove rm undelete);
 
 use File::Spec;
 
-$VERSION = '0.22';
+$VERSION = '0.23';
 
 sub _recurse_dir($);
 
@@ -93,12 +107,12 @@ sub _recurse_dir($)
         print "file: $file\n"
             if $debug;
         if(-f $file || -l $file) {
-            unlink $file
+            unlink($file)
                 or next;
             $ret = 1;
         } elsif (-d $file && ! -l $file) {
 	    _recurse_dir $file;
-	    rmdir $file
+	    rmdir($file)
 	        or next;
 	}
     }
@@ -135,7 +149,7 @@ sub remove(@)
         print "file: $_\n" if $debug;
         if(-f $_ || -l $_) {
             print "file unlink: $_\n" if $debug;
-            unlink $_
+	    unlink($_)
                 and push @removes,$_;
         }
         elsif(-d $_) {
@@ -148,7 +162,7 @@ sub remove(@)
 		$ret = _recurse_dir $_;
 	    }
 	    chmod $save_mode & 0777,$_; # just in case we cannot remove it.
-	    rmdir $_
+	    rmdir($_)
 		and push @removes, $_;
         } else {
 	    print "???: $_\n" if $debug;
@@ -158,9 +172,20 @@ sub remove(@)
     @removes;
 }
 
-sub rm(@)
-{
-    return remove @_;
+sub rm (@) { goto &remove }
+
+sub undelete(@) {
+    local *unlink;
+    local *rmdir;
+    if ($^O =~ /win32/i) {
+	eval 'use Win32::FileOp ();';
+	die "Can't load Win32::FileOp to support the Recycle Bin: \$@ = $@" if length $@;
+	*unlink = \&Win32::FileOp::Recycle;
+	*rmdir = \&Win32::FileOp::Recycle;
+    } else {
+	die "Support for undelete on platform '$^O' not available at this time.\n";
+    }
+    goto &remove;
 }
 
 1;
